phosphoricons_flutter library

Classes

PhosphorDuotoneIconData
Data of a Phosphor icon in the Duotone style.
PhosphorIcon
Widget that renders Phosphor icons in any style, including Duotone.
PhosphorIcons
Central shortcut for all Phosphor icons.
PhosphorIconsBold
Phosphor icons — Bold style.
PhosphorIconsDuotone
Phosphor icons — Duotone style.
PhosphorIconsFill
Phosphor icons — Fill style.
PhosphorIconsLight
Phosphor icons — Light style.
PhosphorIconsRegular
Phosphor icons — Regular style.
PhosphorIconsThin
Phosphor icons — Thin style.

Enums

PhosphorIconsStyle
Available styles for Phosphor icons.

Typedefs

PhosphorIconData = IconData
Alias for IconData maintained for compatibility with code that explicitly references PhosphorIconData as a type.